<?php
require_once '../includes/auth.php';
require_once '../includes/db.php';
require_once '../includes/functions.php';

// 验证管理员登录
if (!isLoggedIn()) {
    header("Location: ../login.php");
    exit;
}

$page_title = "添加香烟数据";
$is_admin_page = true;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = cleanInput($_POST['name'] ?? '');
    $barcode = cleanInput($_POST['barcode'] ?? '');
    $box_code = cleanInput($_POST['box_code'] ?? '');
    $purchase_price = cleanInput($_POST['purchase_price'] ?? '');
    $single_pack_price = cleanInput($_POST['single_pack_price'] ?? '');
    $image_url = '';

    // 处理图片上传
    if (isset($_FILES['image']) && $_FILES['image']['error'] === UPLOAD_ERR_OK) {
        $upload_result = handleImageUpload($_FILES['image']);
        if ($upload_result['success']) {
            $image_url = $upload_result['path'];
        } else {
            $error = $upload_result['message'];
        }
    }

    // 验证必填字段
    if (empty($name)) {
        $error = "香烟名称不能为空";
    }

    // 如果没有错误，保存数据
    if (!isset($error)) {
        try {
            $stmt = $pdo->prepare("INSERT INTO cigarettes 
                (name, barcode, box_code, purchase_price, single_pack_price, image_url) 
                VALUES (?, ?, ?, ?, ?, ?)");
            
            $stmt->execute([
                $name,
                empty($barcode) ? null : $barcode,
                empty($box_code) ? null : $box_code,
                empty($purchase_price) ? null : $purchase_price,
                empty($single_pack_price) ? null : $single_pack_price,
                empty($image_url) ? null : $image_url
            ]);
            
            $success = "香烟数据添加成功！";
            // 清空表单
            $_POST = [];
        } catch (PDOException $e) {
            // 如果上传了图片但数据库出错，删除图片
            if (!empty($image_url) && file_exists("../$image_url")) {
                unlink("../$image_url");
            }
            $error = "数据库错误: " . $e->getMessage();
        }
    }
}

include_once '../includes/header.php';
?>

<div class="admin-container">
    <h1>添加香烟数据</h1>
    
    <?php include '../includes/admin_nav.php'; ?>
    
    <?php if (isset($success)): ?>
        <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
    <?php endif; ?>
    
    <?php if (isset($error)): ?>
        <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
    <?php endif; ?>
    
    <form method="post" enctype="multipart/form-data" class="admin-form">
        <div class="form-group">
            <label for="name">香烟名称 *</label>
            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($_POST['name'] ?? ''); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="barcode">条码</label>
            <input type="text" id="barcode" name="barcode" value="<?php echo htmlspecialchars($_POST['barcode'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="box_code">盒码</label>
            <input type="text" id="box_code" name="box_code" value="<?php echo htmlspecialchars($_POST['box_code'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="purchase_price">进价 (元)</label>
            <input type="number" step="0.01" id="purchase_price" name="purchase_price" value="<?php echo htmlspecialchars($_POST['purchase_price'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="single_pack_price">单包价格 (元)</label>
            <input type="number" step="0.01" id="single_pack_price" name="single_pack_price" value="<?php echo htmlspecialchars($_POST['single_pack_price'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="image">产品图片</label>
            <input type="file" id="image" name="image" accept="image/jpeg,image/png">
            <small class="form-text">支持JPEG/PNG格式，最大2MB</small>
            
            <div id="image-preview" class="image-preview" style="display: none;">
                <img id="preview-image" src="#" alt="图片预览">
                <button type="button" id="remove-image" class="btn btn-sm">移除图片</button>
            </div>
        </div>
        
        <div class="form-actions">
            <button type="submit" class="btn btn-primary">提交</button>
            <button type="reset" class="btn btn-secondary">重置</button>
        </div>
    </form>
</div>

<script>
// 图片预览功能
document.getElementById('image').addEventListener('change', function(e) {
    const file = e.target.files[0];
    if (!file) return;
    
    const preview = document.getElementById('preview-image');
    const previewContainer = document.getElementById('image-preview');
    
    if (file.type.match('image.*')) {
        const reader = new FileReader();
        reader.onload = function(e) {
            preview.src = e.target.result;
            previewContainer.style.display = 'block';
        };
        reader.readAsDataURL(file);
    }
});

// 移除图片
document.getElementById('remove-image').addEventListener('click', function() {
    document.getElementById('image').value = '';
    document.getElementById('image-preview').style.display = 'none';
});
</script>

<?php
include_once '../includes/footer.php';
?>