<?php
require_once '../includes/auth.php';
require_once '../includes/db.php';
require_once '../includes/functions.php';

// 验证管理员登录
if (!isLoggedIn()) {
    header("Location: ../login.php");
    exit;
}

$page_title = "管理香烟数据";
$is_admin_page = true;

// 获取所有香烟数据
try {
    $stmt = $pdo->query("SELECT * FROM cigarettes ORDER BY id DESC");
    $items = $stmt->fetchAll();
} catch (PDOException $e) {
    die("数据库错误: " . $e->getMessage());
}

// 处理删除操作
if (isset($_GET['delete'])) {
    $id = (int)$_GET['delete'];
    
    if ($id > 0) {
        try {
            // 先获取图片路径以便删除图片文件
            $stmt = $pdo->prepare("SELECT image_url FROM cigarettes WHERE id = ?");
            $stmt->execute([$id]);
            $item = $stmt->fetch();
            
            // 删除记录
            $stmt = $pdo->prepare("DELETE FROM cigarettes WHERE id = ?");
            $stmt->execute([$id]);
            
            // 删除图片文件
            if ($item && !empty($item['image_url']) && file_exists("../".$item['image_url'])) {
                unlink("../".$item['image_url']);
            }
            
            $success = "记录删除成功";
            // 刷新页面避免重复提交
            header("Location: manage.php?success=" . urlencode($success));
            exit;
        } catch (PDOException $e) {
            $error = "删除失败: " . $e->getMessage();
        }
    }
}

// 显示操作结果消息
if (isset($_GET['success'])) {
    $success = $_GET['success'];
}

include_once '../includes/header.php';
?>

<div class="admin-container">
    <h1>管理香烟数据</h1>
    
    <?php include '../includes/admin_nav.php'; ?>
    
    <?php if (isset($success)): ?>
        <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
    <?php endif; ?>
    
    <?php if (isset($error)): ?>
        <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
    <?php endif; ?>
    
    <div class="table-responsive">
        <?php if (count($items) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>名称</th>
                        <th>图片</th>
                        <th>条码</th>
                        <th>单包价格</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($items as $item): ?>
                    <tr>
                        <td><?php echo $item['id']; ?></td>
                        <td><?php echo htmlspecialchars($item['name']); ?></td>
                        <td>
                            <?php if (!empty($item['image_url'])): ?>
                                <img src="../<?php echo $item['image_url']; ?>" width="60" height="60" class="item-image">
                            <?php endif; ?>
                        </td>
                        <td><?php echo htmlspecialchars($item['barcode'] ?? '-'); ?></td>
                        <td><?php echo $item['single_pack_price'] ? '¥' . number_format($item['single_pack_price'], 2) : '-'; ?></td>
                        <td class="actions">
                            <a href="edit.php?id=<?php echo $item['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                            <a href="manage.php?delete=<?php echo $item['id']; ?>" class="btn btn-sm btn-delete" onclick="return confirm('确定要删除这条记录吗？此操作不可撤销！')">删除</a>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="no-data">暂无香烟数据</div>
        <?php endif; ?>
    </div>
</div>

<?php
include_once '../includes/footer.php';
?>