<?php
require_once 'config.php';
require_once '../includes/auth.php';

// 只接受POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['error' => '只接受POST请求']);
    exit;
}

// 验证用户登录
if (!isLoggedIn()) {
    echo json_encode(['error' => '未授权访问']);
    exit;
}

// 获取输入数据
$input = json_decode(file_get_contents('php://input'), true);

// 验证必填字段
if (empty($input['name'])) {
    echo json_encode(['error' => '香烟名称不能为空']);
    exit;
}

try {
    // 准备SQL语句
    $stmt = $pdo->prepare("INSERT INTO cigarettes 
        (name, barcode, box_code, purchase_price, single_pack_price, image_url) 
        VALUES (:name, :barcode, :box_code, :purchase_price, :single_pack_price, :image_url)");
    
    // 执行插入
    $stmt->execute([
        ':name' => $input['name'],
        ':barcode' => $input['barcode'] ?? null,
        ':box_code' => $input['box_code'] ?? null,
        ':purchase_price' => $input['purchase_price'] ?? null,
        ':single_pack_price' => $input['single_pack_price'] ?? null,
        ':image_url' => $input['image_url'] ?? null
    ]);
    
    // 返回成功响应
    echo json_encode([
        'success' => true,
        'id' => $pdo->lastInsertId(),
        'message' => '数据添加成功'
    ]);
} catch (PDOException $e) {
    echo json_encode([
        'error' => true,
        'message' => '数据库错误: ' . $e->getMessage()
    ]);
}
?>