<?php
require_once 'config.php';
require_once '../includes/auth.php';

// 只接受POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['error' => '只接受POST请求']);
    exit;
}

// 验证用户登录
if (!isLoggedIn()) {
    echo json_encode(['error' => '未授权访问']);
    exit;
}

// 获取要删除的ID
$id = isset($_POST['id']) ? (int)$_POST['id'] : 0;

if ($id <= 0) {
    echo json_encode(['error' => '无效的ID']);
    exit;
}

try {
    // 先获取图片路径以便删除图片文件
    $stmt = $pdo->prepare("SELECT image_url FROM cigarettes WHERE id = ?");
    $stmt->execute([$id]);
    $item = $stmt->fetch();
    
    // 删除记录
    $stmt = $pdo->prepare("DELETE FROM cigarettes WHERE id = ?");
    $stmt->execute([$id]);
    
    // 删除图片文件
    if ($item && !empty($item['image_url']) && file_exists("../".$item['image_url'])) {
        unlink("../".$item['image_url']);
    }
    
    echo json_encode([
        'success' => true,
        'message' => '删除成功'
    ]);
} catch (PDOException $e) {
    echo json_encode([
        'error' => true,
        'message' => '删除失败: ' . $e->getMessage()
    ]);
}
?>