<?php
require_once 'config.php';
require_once '../includes/auth.php';

// 只接受POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['error' => '只接受POST请求']);
    exit;
}

// 验证用户登录
if (!isLoggedIn()) {
    echo json_encode(['error' => '未授权访问']);
    exit;
}

// 获取输入数据
$input = json_decode(file_get_contents('php://input'), true);

// 验证必填字段
if (empty($input['id']) || empty($input['name'])) {
    echo json_encode(['error' => 'ID和名称不能为空']);
    exit;
}

try {
    // 准备SQL语句
    $stmt = $pdo->prepare("UPDATE cigarettes SET 
        name = :name,
        barcode = :barcode,
        box_code = :box_code,
        purchase_price = :purchase_price,
        single_pack_price = :single_pack_price,
        image_url = :image_url
        WHERE id = :id");
    
    // 执行更新
    $stmt->execute([
        ':id' => $input['id'],
        ':name' => $input['name'],
        ':barcode' => $input['barcode'] ?? null,
        ':box_code' => $input['box_code'] ?? null,
        ':purchase_price' => $input['purchase_price'] ?? null,
        ':single_pack_price' => $input['single_pack_price'] ?? null,
        ':image_url' => $input['image_url'] ?? null
    ]);
    
    // 返回成功响应
    echo json_encode([
        'success' => true,
        'message' => '数据更新成功',
        'affected_rows' => $stmt->rowCount()
    ]);
} catch (PDOException $e) {
    echo json_encode([
        'error' => true,
        'message' => '更新失败: ' . $e->getMessage()
    ]);
}
?>