<?php
// 开启会话
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

/**
 * 检查用户是否已登录
 */
function isLoggedIn() {
    return isset($_SESSION['user_id']) && !empty($_SESSION['user_id']);
}

/**
 * 用户登录验证
 */
function login($username, $password) {
    global $pdo;
    
    // 防止SQL注入
    $username = trim($username);
    
    try {
        // 查询用户
        $stmt = $pdo->prepare("SELECT id, username, password_hash FROM users WHERE username = ? LIMIT 1");
        $stmt->execute([$username]);
        $user = $stmt->fetch();
        
        // 验证密码
        if ($user && password_verify($password, $user['password_hash'])) {
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['username'] = $user['username'];
            return true;
        }
        
        return false;
    } catch (PDOException $e) {
        error_log("登录错误: " . $e->getMessage());
        return false;
    }
}

/**
 * 退出登录
 */
function logout() {
    $_SESSION = [];
    session_destroy();
}

/**
 * 要求登录验证
 */
function requireAuth() {
    if (!isLoggedIn()) {
        header("Location: ../login.php");
        exit;
    }
}

/**
 * 获取当前登录用户信息
 */
function getCurrentUser() {
    if (!isLoggedIn()) return null;
    
    global $pdo;
    try {
        $stmt = $pdo->prepare("SELECT * FROM users WHERE id = ? LIMIT 1");
        $stmt->execute([$_SESSION['user_id']]);
        return $stmt->fetch();
    } catch (PDOException $e) {
        error_log("获取用户信息错误: " . $e->getMessage());
        return null;
    }
}
?>