<?php
/**
 * 清理输入数据
 */
function cleanInput($data) {
    if (is_array($data)) {
        return array_map('cleanInput', $data);
    }
    
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data, ENT_QUOTES | ENT_HTML5, 'UTF-8');
    return $data;
}

/**
 * 处理图片上传
 */
function handleImageUpload($file) {
    // 验证上传错误
    if ($file['error'] !== UPLOAD_ERR_OK) {
        return ['success' => false, 'message' => '文件上传错误'];
    }
    
    // 验证文件类型
    $allowed_types = ['image/jpeg' => 'jpg', 'image/png' => 'png'];
    $file_type = mime_content_type($file['tmp_name']);
    
    if (!array_key_exists($file_type, $allowed_types)) {
        return ['success' => false, 'message' => '只支持JPEG和PNG图片格式'];
    }
    
    // 验证文件大小 (最大2MB)
    $max_size = 2 * 1024 * 1024;
    if ($file['size'] > $max_size) {
        return ['success' => false, 'message' => '图片大小不能超过2MB'];
    }
    
    // 生成唯一文件名
    $ext = $allowed_types[$file_type];
    $filename = uniqid() . '.' . $ext;
    $upload_dir = '../uploads/';
    $upload_path = $upload_dir . $filename;
    
    // 确保上传目录存在
    if (!is_dir($upload_dir)) {
        mkdir($upload_dir, 0755, true);
    }
    
    // 移动文件
    if (move_uploaded_file($file['tmp_name'], $upload_path)) {
        return [
            'success' => true,
            'message' => '上传成功',
            'path' => 'uploads/' . $filename,
            'full_path' => $upload_path
        ];
    }
    
    return ['success' => false, 'message' => '文件移动失败'];
}

/**
 * 重定向到指定URL
 */
function redirect($url, $statusCode = 303) {
    header('Location: ' . $url, true, $statusCode);
    exit;
}

/**
 * 生成CSRF令牌
 */
function generateCsrfToken() {
    if (empty($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    return $_SESSION['csrf_token'];
}

/**
 * 验证CSRF令牌
 */
function verifyCsrfToken($token) {
    return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
}
?>