<?php
require_once 'includes/db.php';
require_once 'includes/functions.php';

$page_title = "香烟查询系统";
include_once 'includes/header.php';
?>

<div class="search-container">
    <h1 class="search-title">香烟查询系统</h1>
    
    <form id="search-form" class="search-form">
        <div class="search-input-group">
            <input type="text" id="search-input" name="query" placeholder="输入香烟名称、条码或盒码..." required>
            <button type="submit" class="search-button">
                <i class="icon-search"></i> 搜索
            </button>
        </div>
    </form>
    
    <div id="search-results" class="results-container">
        <div class="search-intro">
            <p>请输入香烟名称、条码或盒码进行搜索</p>
        </div>
    </div>
</div>

<script>
// 确保DOM完全加载后再执行
document.addEventListener('DOMContentLoaded', function() {
    // 获取关键元素
    const elements = {
        form: document.getElementById('search-form'),
        input: document.getElementById('search-input'),
        results: document.getElementById('search-results')
    };
    
    // 验证元素是否存在
    for (const [key, element] of Object.entries(elements)) {
        if (!element) {
            console.error(`未找到元素: ${key}`);
            return;
        }
    }
    
    // 搜索表单提交处理
    elements.form.addEventListener('submit', function(e) {
        e.preventDefault();
        const query = elements.input.value.trim();
        
        if (!query) {
            showAlert('请输入搜索内容', 'error');
            return;
        }
        
        searchProducts(query, elements.results);
    });
    
    /**
     * 执行搜索
     */
    function searchProducts(query, container) {
        container.innerHTML = `
            <div class="loading">
                <div class="spinner"></div>
                <p>搜索中...</p>
            </div>
        `;
        
        fetch(`api/search.php?query=${encodeURIComponent(query)}`)
            .then(response => {
                if (!response.ok) throw new Error('网络响应不正常');
                return response.json();
            })
            .then(data => {
                if (data.error) throw new Error(data.error);
                displayResults(data, container);
            })
            .catch(error => {
                console.error('搜索错误:', error);
                container.innerHTML = `
                    <div class="error">
                        <p>搜索失败: ${error.message}</p>
                        <button class="btn-retry" onclick="window.location.reload()">重试</button>
                    </div>
                `;
            });
    }
    
    /**
     * 显示搜索结果
     */
    function displayResults(data, container) {
        if (!data || data.length === 0) {
            container.innerHTML = `
                <div class="no-results">
                    <p>没有找到匹配的结果</p>
                </div>
            `;
            return;
        }
        
        let html = '<div class="results-grid">';
        data.forEach(item => {
            html += `
            <div class="product-card">
                <div class="product-image">
                    <img src="${item.image_url || 'assets/images/no-image.jpg'}" 
                         alt="${escapeHtml(item.name)}"
                         onerror="this.src='assets/images/no-image.jpg'">
                </div>
                <div class="product-details">
                    <h3>${escapeHtml(item.name)}</h3>
                    <p><strong>条码:</strong> ${item.barcode || '无'}</p>
                    <p><strong>盒码:</strong> ${item.box_code || '无'}</p>
                    <p><strong>价格:</strong> ${item.single_pack_price ? '¥'+item.single_pack_price : '无'}</p>
                </div>
            </div>
            `;
        });
        html += '</div>';
        
        container.innerHTML = html;
    }
    
    /**
     * HTML转义
     */
    function escapeHtml(unsafe) {
        return unsafe
            .replace(/&/g, "&amp;")
            .replace(/</g, "&lt;")
            .replace(/>/g, "&gt;")
            .replace(/"/g, "&quot;")
            .replace(/'/g, "&#039;");
    }
    
    /**
     * 显示提示信息
     */
    function showAlert(message, type = 'info') {
        const alert = document.createElement('div');
        alert.className = `alert alert-${type}`;
        alert.textContent = message;
        document.body.appendChild(alert);
        
        setTimeout(() => {
            alert.remove();
        }, 3000);
    }
});
</script>

<?php
include_once 'includes/footer.php';
?>