<?php
require_once 'includes/db.php';

$page_title = "系统安装";
include_once 'includes/header.php';

// 检查是否已安装
try {
    $stmt = $pdo->query("SHOW TABLES LIKE 'users'");
    $isInstalled = $stmt->rowCount() > 0;
    
    if ($isInstalled && !isset($_GET['force'])) {
        die('<div class="container"><div class="alert alert-error">系统已安装，如需重新安装请添加?force参数</div></div>');
    }
} catch (PDOException $e) {
    // 忽略错误，继续安装
}

// 处理安装表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 创建表结构
        $pdo->exec("DROP TABLE IF EXISTS cigarettes");
        $pdo->exec("DROP TABLE IF EXISTS users");
        
        // 创建用户表
        $pdo->exec("CREATE TABLE `users` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `username` varchar(50) NOT NULL,
            `password_hash` varchar(255) NOT NULL,
            `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `username` (`username`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4");
        
        // 创建香烟数据表
        $pdo->exec("CREATE TABLE `cigarettes` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `name` varchar(100) NOT NULL COMMENT '香烟名称',
            `barcode` varchar(50) DEFAULT NULL COMMENT '条码',
            `box_code` varchar(50) DEFAULT NULL COMMENT '盒码',
            `purchase_price` decimal(10,2) DEFAULT NULL COMMENT '进价',
            `single_pack_price` decimal(10,2) DEFAULT NULL COMMENT '单包价格',
            `image_url` varchar(255) DEFAULT NULL COMMENT '图片地址',
            `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
            PRIMARY KEY (`id`),
            KEY `idx_name` (`name`) COMMENT '名称索引'
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='香烟产品表'");
        
        // 添加管理员账户
        $username = 'admin';
        $password = $_POST['admin_password'] ?? 'admin123';
        $passwordHash = password_hash($password, PASSWORD_DEFAULT);
        
        $stmt = $pdo->prepare("INSERT INTO users (username, password_hash) VALUES (?, ?)");
        $stmt->execute([$username, $passwordHash]);
        
        // 创建uploads目录
        if (!is_dir('uploads')) {
            mkdir('uploads', 0755, true);
        }
        
        $success = true;
    } catch (PDOException $e) {
        $error = "安装失败: " . $e->getMessage();
    }
}
?>

<div class="install-container">
    <h1>系统安装向导</h1>
    
    <?php if (isset($error)): ?>
        <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
    <?php endif; ?>
    
    <?php if (isset($success)): ?>
        <div class="alert alert-success">
            <p>系统安装成功！</p>
            <p>管理员账号: admin</p>
            <p>管理员密码: <?php echo htmlspecialchars($password ?? 'admin123'); ?></p>
            <p><a href="login.php" class="btn btn-primary">前往登录</a></p>
        </div>
    <?php else: ?>
        <form method="post" class="install-form">
            <div class="form-group">
                <label for="admin_password">设置管理员密码</label>
                <input type="password" id="admin_password" name="admin_password" required>
                <small class="form-text">默认用户名: admin</small>
            </div>
            
            <div class="form-group">
                <label>
                    <input type="checkbox" name="confirm" required>
                    我确认要安装系统，这将清除所有现有数据
                </label>
            </div>
            
            <div class="form-actions">
                <button type="submit" class="btn btn-primary">开始安装</button>
            </div>
        </form>
    <?php endif; ?>
</div>

<?php
include_once 'includes/footer.php';
?>