<?php
// 确保这是文件的第一行
require_once 'includes/db.php';
require_once 'includes/auth.php';
require_once 'includes/functions.php'; // 添加这行引入函数文件

// 开启会话
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// 如果已登录，重定向到管理页面
if (isLoggedIn()) {
    header("Location: admin/manage.php");
    exit;
}

// 处理登录表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 移除cleanInput调用，直接使用trim过滤
    $username = trim($_POST['username'] ?? '');
    $password = trim($_POST['password'] ?? '');
    
    if (empty($username) || empty($password)) {
        $error = "用户名和密码不能为空";
    } else {
        if (login($username, $password)) {
            // 登录成功，重定向到管理页面
            header("Location: admin/manage.php");
            exit;
        } else {
            $error = "用户名或密码错误";
        }
    }
}

$page_title = "管理员登录";
include_once 'includes/header.php';
?>

<div class="login-page">
    <div class="login-container">
        <div class="login-header">
            <h1>管理员登录</h1>
            <p>请输入您的凭据访问管理系统</p>
        </div>
        
        <?php if (isset($error)): ?>
            <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>
        
        <form method="post" class="login-form">
            <div class="form-group">
                <label for="username">用户名</label>
                <input type="text" id="username" name="username" required autofocus>
            </div>
            
            <div class="form-group">
                <label for="password">密码</label>
                <input type="password" id="password" name="password" required>
            </div>
            
            <div class="form-actions">
                <button type="submit" class="btn btn-primary btn-block">登录</button>
            </div>
        </form>
    </div>
</div>

<?php
include_once 'includes/footer.php';
?>